@@ -134,3 +134,7 @@ def main():
     if args.banner_name is not None:
         Transport._CLIENT_ID = args.banner_name
     proxy.start()
+
+
+if __name__ == '__main__':
+    main()
